from django import forms

from .models import *

class PSearch_form(forms.Form):
	PSearch = forms.CharField(label='Recherche', max_length=128)

class Edit_srv_form(forms.ModelForm):
	class Meta:
		model = PIS
		exclude = ['PIC_NUnic']
		
		widgets = {
			'PIS_Fonctionnalite': forms.Textarea(attrs={'cols': 90, 'rows': 3}),
			'PIS_Commentaires': forms.Textarea(attrs={'cols': 90, 'rows': 3}),
			}

class Edit_switch_form(forms.ModelForm):
	class Meta:
		model = Swich
		exclude = ['SW_Update_Port']
		
		widgets = {
			'SW_Commentaires': forms.Textarea(attrs={'cols': 90, 'rows': 2}),
			}

class Update_switch_port(forms.ModelForm):
	class Meta:
		model = Swich
		fields = ['SW_Update_Port']
		
		widgets = {
			'SW_Update_Port': forms.Textarea(attrs={'cols': 90, 'rows': 20}),
			}

class Edit_switch_port_form(forms.ModelForm):
	class Meta:
		model = Port_Link
		exclude = ['PL_Port']
		
		widgets = {
			'PL_Commentaires': forms.Textarea(attrs={'cols': 90, 'rows': 2}),
			}

class Edit_user_mini_form(forms.ModelForm):
	class Meta:
		model = PIC
		fields = ['PIC_Site', 'PIC_Service', 'PIC_L_Chassi_Type', 'PIC_Nom_netbios', 'PIC_Utilisateur', 'PIC_Adresse_IP', 'PIC_Adresse_Mac', 'PIC_SN', 'PIC_Local', 'PIC_Precisions', 'PIC_Commentaires']
		widgets = {
			'PIC_Precisions': forms.Textarea(attrs={'cols': 90, 'rows': 1}),
			'PIC_Commentaires': forms.Textarea(attrs={'cols': 90, 'rows': 3}),
			}
		labels = {
			'PIC_Service': 'Service',
		}

class Edit_imp_form(forms.ModelForm):
	class Meta:
		model = PIC
		fields = ['PIC_Site', 'PIC_Service', 'PIC_L_Chassi_Type', 'PIC_Nom_netbios', 'PIC_Utilisateur', 'PIC_Adresse_IP', 'PIC_Marque', 'PIC_Type', 'PIC_SN', 'PIC_Precisions', 'PIC_Local' , 'PIC_Commentaires']
		widgets = {
			'PIC_Precisions': forms.Textarea(attrs={'cols': 90, 'rows': 1}),
			'PIC_Commentaires': forms.Textarea(attrs={'cols': 90, 'rows': 3}),
			}
		labels = {
			'PIC_Service': 'Service',
		}

class Edit_user_statut_form(forms.ModelForm):
	class Meta:
		model = PIC
		fields = ['PIC_L_Statut', 'PIC_Accessory', 'PIC_Deg', 'PIC_is_for_Cadre', 'PIC_with_Office']
		widgets = {}


